skhubness.neighbors.DistanceMetric
==================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: DistanceMetric

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DistanceMetric.__init__
      ~DistanceMetric.dist_to_rdist
      ~DistanceMetric.get_metric
      ~DistanceMetric.pairwise
      ~DistanceMetric.rdist_to_dist
   
   

   
   
   